package App::VersionUtils;

our $DATE = '2016-08-25'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Command-line utilities related to version number

__END__

=pod

=encoding UTF-8

=head1 NAME

App::VersionUtils - Command-line utilities related to version number

=head1 VERSION

This document describes version 0.002 of App::VersionUtils (from Perl distribution App-VersionUtils), released on 2016-08-25.

=head1 DESCRIPTION

This distribution provides the following command-line utilities related to
version number:

=over

=item * L<compare-version>

=item * L<normalize-version>

=item * L<sort-versions>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-VersionUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-VersionUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-VersionUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
